{% if GA_TRACKING_ID %}
<script type="text/javascript">

    var _gaq = _gaq || [];
    _gaq.push(['_setAccount', '{{GA_TRACKING_ID}}']);
    {% include 'ga_tracking/ga_track.js' %}

    (function() {
    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
    })();

</script>
{% endif %}
